<?php
class FLX_Admin {
	public static $plugin, $settings, $className;
	public static $name = 'File Label Express';
	public static $slug = 'flx';
	public static $globalName = 'flxInstalledTools';
	public static function mainMenu() {
		if(!current_user_can('manage_options')) :
			wp_die(__('You do not have sufficient permissions to access this page.'));
		endif;
		if(!empty($GLOBALS[self::$globalName])) : ?>
			<?php $parsedown = new Parsedown(); ?>
			<div id="help">
				<?= $parsedown->text(file_get_contents(dirname(dirname(__FILE__)).DIRECTORY_SEPARATOR.'README.md')); ?>
			</div>
			<div id="modal" style="display:none;"></div>
			<a style="display:none;" href="#TB_inline?&width=600&height=550&inlineId=modal" class="thickbox" id="thickbox"></a>
		<?php endif;
	}

	public static function registerMainMenu() {
		add_menu_page(self::$name, self::$name, "manage_options", self::$slug, array(self::$className, 'mainMenu'));
	}

	public static function registerSettings() {
		$group = self::$plugin->slug.'-settings-group';
		if(!empty(self::$settings)) :
			foreach(self::$settings as $setting => $type) :
				register_setting($group, $setting);
			endforeach;
		endif;
	}

	public static function setup($array) {
		$settings = array();
		$name = 'Generic Plugin';
		$description = 'Generic Plugin';
		extract($array, EXTR_OVERWRITE);
		self::$className = get_class();
		$slug = sanitize_title($name);
		self::$plugin = (object) array(
			'slug' => $slug,
			'name' => $name,
			'desciption' => $description
		);
		self::$settings = $settings;
		$GLOBALS[self::$globalName][] = self::$plugin;
		add_action('admin_init', array(self::$className, 'registerSettings'));
		$regVar = self::$globalName.'registered';
		if(!isset($GLOBALS[$regVar])) :
			add_action('admin_menu', array(self::$className, 'registerMainMenu'));
			$GLOBALS[$regVar] = true;
		endif;
		add_action('admin_menu', array(self::$className, 'registerSubMenu'));
	}

	public static function settingsPage() {
	?>
		<div class="wrap">
			<h2><?php echo self::$plugin->name; ?></h2>

			<form method="post" action="options.php">
			<?php settings_fields(self::$plugin->slug.'-settings-group'); ?>
			<?php do_settings_sections(self::$plugin->slug.'-settings-group'); ?>

				<table class="form-table">
					<?php if(!empty(self::$settings)) : ?>
					<?php
					foreach(self::$settings as $setting => $type) :
						$hidden     = false;
						$conditions = array();

						$title = ucwords(str_replace('-', ' ', $setting));

						if(is_array($type))
						{
							$field = $type;

							$type = $field['type'];

							if( ! empty($field['conditions']))
							{
								$conditions = $field['conditions'];

								$hidden = true;;
							}
							
							if( ! empty($field['title']))
							{
								$title = $field['title'];
							}
						}

						$s = str_replace('-', '_', $setting);
					?>
					<tr class="settings_field" valign="top" data-key="<?php echo $setting; ?>" style="<?php echo $hidden ? 'display:none;' : ''; ?>" data-conditions='<?php echo json_encode($conditions); ?>'>
						<?php if( $type == 'separator' ) : ?>
						<td colspan="2"><hr /></td>
						<?php else : ?>
						<th scope="row"><?php echo $title; ?></th>
						<?php if($type == 'textarea') : ?>
						<td><textarea name ="<?php echo $setting; ?>"><?php echo get_option($setting); ?></textarea> <code>[<?php echo $s; ?>]</code></td>
						<?php elseif($type == 'media') : ?>
						<td class="media" data-id="i<?= uniqid(); ?>">
						<div class='image-preview-wrapper'>
							<img src='' style='max-height: 100px;margin-bottom:15px'>
						</div>
						<input type="button" class="button" value="<?php _e( 'Upload image' ); ?>" />
						<input type='hidden' name='<?php echo $setting; ?>' value="<?php echo get_option($setting); ?>">
						</td>
						<?php else : ?>
							<?php if(strpos($type, 'select') !== false) : ?>
								<?php $options = explode(',', str_replace('select:', '', $type)); ?>
								<td>
								<select name="<?php echo $setting; ?>">
									<?php foreach($options as $option) : ?>
									<option value="<?php echo $option; ?>"<?php echo (get_option($setting) == $option ? ' selected' : ''); ?>><?php echo $option; ?></option>
									<?php endforeach; ?>
								</select>
								</td>
							<?php else : ?>
								<td><input type="<?php echo $type; ?>" name="<?php echo $setting; ?>" value="<?php echo get_option($setting); ?>" /> <code>[<?php echo $s; ?>]</code></td>
							<?php endif; ?>
						<?php endif; ?>
						<?php endif; ?>
					</tr>
					<?php endforeach; ?>
					<?php endif; ?>
				</table>
				<?php submit_button(); ?>
			</form>

			<div>
			</div>
		</div>
	<?php
	}

	public static function registerSubMenu() {
		add_submenu_page(self::$slug, self::$plugin->name, self::$plugin->name, 'manage_options', self::$plugin->slug, array(self::$className, 'settingsPage'));
	}
}
$mySettings = [
	'flx_dealer'   => 'text',
	'flx_legacy'   => 'url',
	'flx_reseller' => 'select:true,false',
	'flx_ip'       => 'text'
];

FLX_Admin::setup([
	'name' => 'FLX Options',
	'description' => 'Integrates with filelabel.co for label creation',
	'settings' => $mySettings
]);